/*
 * sensors-ipv6.c
 *
 * Copyright (c) 2012, ROSAND Technologies
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the Institute nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * This file is part of the Contiki operating system.
 *
 */

#include "contiki.h"
#include "contiki-lib.h"
#include "contiki-net.h"

#include <string.h>
#include "dev/leds.h"
#include "dev/button-sensor.h"
#include "dev/rmote-sensors.h"

#define SEND_INTERVAL           2 * CLOCK_SECOND
#define MAX_PAYLOAD_LEN         40

static char buf[MAX_PAYLOAD_LEN];

#define REMOTE_CONN_PORT 3000
#define LOCAL_CONN_PORT  3002
static struct uip_udp_conn *g_conn;

/*---------------------------------------------------------------------------*/
PROCESS(sensors_ipv6_process, "Sensors IPv6 process");
AUTOSTART_PROCESSES(&sensors_ipv6_process);
/*---------------------------------------------------------------------------*/
static void
tcpip_handler(void)
{
  if(uip_newdata()) {
    return;
  }
  return;
}
/*---------------------------------------------------------------------------*/
static void
event_handler(uint8_t *data)
{
  uint8_t len;

  if(uip_ds6_get_global(ADDR_PREFERRED)) {
    len = *data;
    uip_udp_packet_send(g_conn, data, len);
  }
}
/*---------------------------------------------------------------------------*/
PROCESS_THREAD(sensors_ipv6_process, ev, data)
{
  uip_ipaddr_t ipaddr;

  PROCESS_BEGIN();

  uip_ip6addr(&ipaddr,0x2001,0xdb8,0x01,0,0,0,0,0x01);
  g_conn = udp_new(&ipaddr, UIP_HTONS(REMOTE_CONN_PORT), NULL);
  udp_bind(g_conn, UIP_HTONS(LOCAL_CONN_PORT));

  while(1) {
    PROCESS_YIELD();
    if(ev == tcpip_event) {
      tcpip_handler();
    } else if(ev == rmote_event) {
      event_handler(data);
    }
  }

  PROCESS_END();
}
/*---------------------------------------------------------------------------*/
