/*
 * contiki-rmote-main.c
 *
 * Copyright (c) 2012, ROSAND Technologies
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the Institute nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * This file is part of the Contiki operating system.
 *
 */

#define DEBUG 0
#if DEBUG
#define PRINTF(FORMAT,args...) printf_P(PSTR(FORMAT),##args)
#else
#define PRINTF(...)
#endif /* DEBUG */

#include <avr/signature.h>
#include <avr/pgmspace.h>
#include <avr/fuse.h>
#include <avr/eeprom.h>
#include <util/delay.h>
#include <stdio.h>
#include <string.h>

#include "contiki.h"
#include "contiki-net.h"
#include "sys/autostart.h"
#include "dev/watchdog.h"
#include "rmote.h"

#include "net/netstack.h"
#include "net/rime.h"
#include "dev/rs232.h"
#include "dev/serial-line.h"

#include "xmem.h"
#include "config.h"
#include "rmote-sensors.h"

#include "dev/leds.h"

/*-------------------------------------------------------------------------*/
void
set_rime_addr(void)
{
  rmote_set_pan_addr(IEEE802154_CONF_PANID, (uint8_t *) &rimeaddr_node_addr);

}
/*-------------------------Low level initialization------------------------*/
/*------Done in a subroutine to keep main routine stack usage small--------*/
static void
initialize(void)
{
  leds_init();
  xmem_init();
  watchdog_init();
  clock_init();
  config_init();

  /* Initialize process subsystem */
  process_init();

  /* etimer must be started before ctimer_init */
  process_start(&etimer_process, NULL);
  ctimer_init();

  PRINTF("CONTIKI Started\n");

  /* Set up RIME address */
  set_rime_addr();

  /* Set up 802.14.5 channel number */
  rmote_set_channel(CHANNEL_802_15_4);

  /* Set up 802.15.4 transmit power */
  rmote_set_txpower(0x35);

  /* Initialize the network stack */
  netstack_init();

  /* Start sensors */
  init_sensors();

  /* Set up local IPv6 address */
  memcpy(&uip_lladdr.addr, &rimeaddr_node_addr, sizeof(uip_lladdr.addr));

  /* Start TCPIP process */
  process_start(&tcpip_process, NULL);

  /* Autostart other processes */
  autostart_start(autostart_processes);
}

/*-------------------------------------------------------------------------*/
/*------------------------- Main Scheduler loop----------------------------*/
/*-------------------------------------------------------------------------*/
int
main(void)
{
  initialize();

  /* Start watchdog */
  watchdog_start();

  /* Every thing is OK */
  leds_on(LEDS_GREEN);

  while(1) {
    process_run();
    watchdog_periodic();
  }
  return 0;
}

/*---------------------------------------------------------------------------*/

void log_message(char *m1, char *m2)
{
  PRINTF("%s%s\n", m1, m2);
}
