/*
 * env-sensor.h
 *
 * Copyright (c) 2012, ROSAND Technologies
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the Institute nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * This file is part of the Contiki operating system.
 *
 */

#ifndef ENV_SENSOR_H
#define ENV_SENSOR_H

#include "lib/sensors.h"

#ifdef ENV_SENSOR_CONF_ON
#define ENV_SENSOR_ON              ENV_SENSOR_CONF_ON
#endif

#define ENV_HUMID                   0
#define ENV_TEMP                    1
#define ENV_LUX                     2

#define ENV_TEMP_LENGTH             2                 /* Size in bytes */
#define ENV_HUMID_LENGTH            2
#define ENV_LUX_LENGTH              2

#define ENV_SENSOR_POLL_INTERVAL    4                 /* Polling interval in seconds */

/* Temperature sensor accuracy is 100th degree
 * ENV_TEMP_SCALE provides the precision needed
 *      ENV_TEMP_SCALE = 1    --> 100th degree
 *      ENV_TEMP_SCALE = 10   --> 10th degree
 *      ENV_TEMP_SCALE = 100  --> degree
 */

#ifndef ENV_TEMP_SCALE
#define ENV_TEMP_SCALE          10          /* 10th degree precision */
#endif /* ENV_TEMP_SCALE */

#define ENV_LUX_CHANNEL          2          /* ADC channel (PF pin number) of the Light sensor */

extern const struct sensors_sensor env_sensor;

#endif /* ENV_SENSOR_H */
