/*
 * gps-sensor.c
 *
 * Copyright (c) 2012, ROSAND Technologies
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the Institute nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * This file is part of the Contiki operating system.
 *
 */

#include <stdint.h>
#include "sys/clock.h"
#include "defs.h"
#include "dev/gps-sensor.h"
#include "dev/adc.h"
#include "dev/i2c.h"

#define I2C_ADDRESS             0x45    /* GPS Module default address */
#define I2C_CYCLE               3000    /* Delay in usecs */
#define I2C_LENGTH              0x08    /* Length of sensor data */

/*-------------------------------------------------------------------------------
 * fetch()
 * @brief       Fetch data (latitude/longitude) from the GPS module
 *
 *      Latitude: 4 bytes
 *      Longitude: 4 bytes
 */
static int
fetch(uint8_t sensor)
{
  uint8_t buf[I2C_LENGTH];
  uint16_t value = 0;

  i2c_init(I2C_MASTER);
  //  i2c_send(I2C_ADDRESS, buf, 0);                 /* Wake up the sensor */
  //  clock_delay_usec(I2C_CYCLE);                   /* Wait 3ms */
  i2c_receive(I2C_ADDRESS, buf, I2C_LENGTH);     /* Fetch 8 bytes sensor data */
  i2c_init(I2C_SLAVE);

  switch(sensor) {
  case GPS_LAT_LOW:
    value = BUILD_UINT16(buf[1], buf[0]);
    break;
  case GPS_LAT_HIGH:
    value = BUILD_UINT16(buf[3], buf[2]);
    break;
  case GPS_LON_LOW:
    value = BUILD_UINT16(buf[5], buf[4]);
    break;
  case GPS_LON_HIGH:
    value = BUILD_UINT16(buf[7], buf[6]);
    break;
  default:
    value = -1;
  }
  return value;
}

/*-------------------------------------------------------------------------------
 * temp_value()
 * @brief       Return GPS sensor value:
 */
static int
value(int type)
{
  return fetch(type);
}

/*-------------------------------------------------------------------------------
 * configure()
 */
static int
configure(int type, int c)
{
  switch (type) {
  case SENSORS_ACTIVE:
    if (c) {
      return 1;
    }
    else {
      return 0;
    }
  default:
    return 0;
  }
}

/*-------------------------------------------------------------------------------
 * status()
 */
static int
status(int type)
{
  switch (type) {
  case SENSORS_ACTIVE:
  case SENSORS_READY:
    return 1;
  default:
    return 0;
  }
}

SENSORS_SENSOR(gps_sensor, "GPS Sensor", value, configure, status);
