/*
 * spi-arch.h
 *
 * Copyright (c) 2012, ROSAND Technologies
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the Institute nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * This file is part of the Contiki operating system.
 *
 */

#ifndef _SPI_ARCH_H_

#define _SPI_ARCH_H_

#include <avr/io.h>
#include "dev/defs.h"

/* SPI, USART and Timer ports */
#define SSPORT              B
#define SSPIN               0
#define SPIPORT             B
#define MOSIPIN             2
#define MISOPIN             3
#define SCKPIN              1

/* SPI Types */
#define SPI_MASTER          0
#define SPI_SLAVE           1

/**
 * \name Pin macros
 * \brief These macros convert the platform-specific pin defines into names and functions
 *       that the source code can directly use.
 * \{
 */

#define HAL_SS_PIN            SSPIN               /**< The slave select pin. */
#define HAL_SCK_PIN           SCKPIN              /**< Data bit for SCK. */
#define HAL_MOSI_PIN          MOSIPIN
#define HAL_MISO_PIN          MISOPIN
#define HAL_PORT_SPI          PORT(SPIPORT)       /**< The SPI module is located on PORTB. */
#define HAL_PORT_SS           PORT(SSPORT)
#define HAL_PORT_SCK          PORT(SCKPORT)
#define HAL_PORT_MOSI         PORT(MOSIPORT)      /**< The SPI module uses GPIO might be split on different ports. */
#define HAL_PORT_MISO         PORT(MISOPORT)      /**< The SPI module uses GPIO might be split on different ports. */
#define HAL_DDR_SPI           DDR(SPIPORT)        /**< Data Direction Register for PORTB. */
#define HAL_DDR_SS            DDR(SSPORT)         /**< Data Direction Register for MISO GPIO pin. */
#define HAL_DDR_SCK           DDR(SCKPORT)        /**< Data Direction Register for MISO GPIO pin. */
#define HAL_DDR_MOSI          DDR(MOSIPORT)       /**< Data Direction Register for MISO GPIO pin. */
#define HAL_DDR_MISO          DDR(MISOPORT)       /**< Data Direction Register for MOSI GPIO pin. */
#define HAL_PIN_SS            PIN(SSPORT)         /**< Pin where IRQ is connected */
#define HAL_DD_SS             SSPIN               /**< Data Direction bit for SS. */
#define HAL_DD_SCK            SCKPIN              /**< Data Direction bit for SCK. */
#define HAL_DD_MOSI           MOSIPIN             /**< Data Direction bit for MOSI. */
#define HAL_DD_MISO           MISOPIN             /**< Data Direction bit for MISO. */
/** \} */

#define HAL_SS_HIGH( ) (HAL_PORT_SS |= (1 << HAL_SS_PIN))  /**< MACRO for pulling SS high. */
#define HAL_SS_LOW( )  (HAL_PORT_SS &= ~(1 << HAL_SS_PIN)) /**< MACRO for pulling SS low. */

/* SPI input/output data registers */
#define SPI_TXBUF SPDR
#define SPI_RXBUF SPDR

#define BUFFER_SIZE          128
#define BUFFER_MASK          (BUFFER_SIZE -1)

#define SPI_WAITFOREOTx()    while ((SPSR & (1 << SPIF)) == 0)       /* Reception complete */
#define SPI_WAITFOREORx()    while ((SPSR & (1 << SPIF)) == 0)       /* Reception complete */

void spi_init(void);
void spi_flush(void);
uint8_t spi_read(uint8_t *buf, uint8_t len);
uint8_t spi_write(uint8_t *buf, uint8_t len);

#endif /* _SPI_ARCH_H_ */
